Learn R Programming

googleComputeEngineR (version 0.1.0)

AttachedDisk: AttachedDisk Object

Description

AttachedDisk Object

Usage

AttachedDisk(autoDelete = NULL, boot = NULL, deviceName = NULL, diskEncryptionKey = NULL, index = NULL, initializeParams = NULL, interface = NULL, licenses = NULL, mode = NULL, source = NULL, type = NULL)

Arguments

autoDelete
Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance)
boot
Indicates that this is a boot disk
deviceName
Specifies a unique device name of your choice that is reflected into the /dev/disk/by-id/google-* tree of a Linux operating system running within the instance
diskEncryptionKey
Encrypts or decrypts a disk using a customer-supplied encryption key
index
Assigns a zero-based index to this disk, where 0 is reserved for the boot disk
initializeParams
A gce_make_boot_disk object for creating boot disks. Cannot be used with source also defined.
interface
Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME
licenses
[Output Only] Any valid publicly visible licenses
mode
The mode in which to attach this disk, either READ_WRITE or READ_ONLY
source
Specifies a valid partial or full URL to an existing Persistent Disk resource
type
Specifies the type of the disk, either SCRATCH or PERSISTENT

Value

AttachedDisk object

Details

An instance-attached disk resource.

See Also

Other AttachedDisk functions: gce_attach_disk