Learn R Programming

googleComputeEngineR (version 0.1.0)

Instance: Instance Object

Description

Instance Object

Usage

Instance(name = NULL, machineType = NULL, canIpForward = NULL, description = NULL, disks = NULL, metadata = NULL, networkInterfaces = NULL, scheduling = NULL, serviceAccounts = NULL, tags = NULL)

Arguments

name
The name of the resource, provided by the client when initially creating the resource
machineType
Full or partial URL of the machine type resource to use for this instance, in the format: zones/zone/machineTypes/machine-type
canIpForward
Allows this instance to send and receive packets with non-matching destination or source IPs
description
An optional description of this resource
disks
The source image used to create this disk
metadata
A named list of metadata key/value pairs assigned to this instance
networkInterfaces
An array of configurations for this interface
scheduling
Scheduling options for this instance
serviceAccounts
A list of service accounts, with their specified scopes, authorized for this instance
tags
A list of tags to apply to this instance

Value

Instance object

Details

An Instance resource.