Rdocumentation
powered by
Learn R Programming
googleComputeEngineR (version 0.1.0)
cli_tools: See if ssh or scp is installed From https://github.com/sckott/analogsea/blob/master/R/zzz.R
Description
See if ssh or scp is installed From https://github.com/sckott/analogsea/blob/master/R/zzz.R
Usage
cli_tools(ip)
Arguments