Learn R Programming

googleComputeEngineR (version 0.1.0)

container_update_info: Update the information about a container.

Description

This queries docker (on the host) for information about the container, and saves the returned information into a container object, which is returned. This does not use reference semantics, so if you want to store the updated information, you need to save the result.

Usage

container_update_info(container)

Arguments

container
A container object

Examples

Run this code
## Not run: 
# con <- container_update_info(con)
# ## End(Not run)

Run the code above in your browser using DataLab