Learn R Programming

googleComputeEngineR (version 0.1.0)

gce_delete_disk: Deletes the specified persistent disk.

Description

Deleting a disk removes its data permanently and is irreversible.

Usage

gce_delete_disk(disk, project = gce_get_global_project(), zone = gce_get_global_zone())

Arguments

disk
Name of the persistent disk to delete
project
Project ID for this request
zone
The name of the zone for this request

Details

However, deleting a disk does not delete any snapshots previously made from the disk. You must separately delete snapshots.

Authentication scopes used by this function are:

  • https://www.googleapis.com/auth/cloud-platform
  • https://www.googleapis.com/auth/compute

See Also

Google Documentation