Learn R Programming

googleComputeEngineR (version 0.1.0)

gce_get_external_ip: Get the external IP of an instance

Description

Get the external IP of an instance

Usage

gce_get_external_ip(instance, verbose = TRUE, ...)

Arguments

instance
Name or instance object to find the external IP for
verbose
Give a user message about the IP
...
passed to gce_get_instance

This is a helper to extract the external IP of an instance

Value

The external IP