Rdocumentation
powered by
Learn R Programming
googleComputeEngineR (version 0.1.0)
gce_global_project: Set global project name
Description
Set a project name used for this R session
Usage
gce_global_project(project = gce_get_global_project())
Arguments
project
project name you want this session to use by default, or a project object
Value
The project name (invisibly)
Details
This sets a project to a global environment value so you don't need to supply the project argument to other API calls.