Learn R Programming

googleComputeEngineR (version 0.1.0)

gce_list_images: Retrieves the list of private images available to the specified project.

Description

Retrieves the list of private images available to the specified project.

Usage

gce_list_images(image_project, filter = NULL, maxResults = NULL, pageToken = NULL)

Arguments

image_project
Project ID for this request
filter
Sets a filter expression for filtering listed resources, in the form filter=expression
maxResults
The maximum number of results per page that should be returned
pageToken
Specifies a page token to use

Details

Authentication scopes used by this function are:
  • https://www.googleapis.com/auth/cloud-platform
  • https://www.googleapis.com/auth/compute
  • https://www.googleapis.com/auth/compute.readonly

If you want to get a list of publicly-available images, use this method to make a request to the respective image project, such as debian-cloud, windows-cloud or google-containers.

See Also

Google Documentation