Rdocumentation
powered by
Learn R Programming
googleComputeEngineR (version 0.1.0)
gce_list_zones: Retrieves the list of Zone resources available to the specified project.
Description
Retrieves the list of Zone resources available to the specified project.
Usage
gce_list_zones(project, filter = NULL, maxResults = NULL, pageToken = NULL)
Arguments
project
Project ID for this request
filter
Sets a filter expression for filtering listed resources, in the form filter=expression
maxResults
The maximum number of results per page that should be returned
pageToken
Specifies a page token to use
Details
Authentication scopes used by this function are:
https://www.googleapis.com/auth/cloud-platform
https://www.googleapis.com/auth/compute
https://www.googleapis.com/auth/compute.readonly
See Also
Google Documentation