gce_make_boot_disk: Make a boot disk for attachment to an instance
Description
Make a boot disk for attachment to an instance
Usage
gce_make_boot_disk(diskName = NULL, diskSizeGb = NULL, diskType = NULL, sourceImage = NULL, sourceImageEncryptionKey = NULL)
Arguments
diskName
Specifies the disk name
diskSizeGb
Specifies the size of the disk in base-2 GB
diskType
Specifies the disk type to use to create the instance
sourceImage
The source image used to create this disk
sourceImageEncryptionKey
The customer-supplied encryption key of the source image
Value
AttachedDiskInitializeParams object
Details
Specifies the parameters for a new disk that will be created alongside the new instance. Use initialization parameters to create boot disks or local SSDs attached to the new instance.
This property is mutually exclusive with the source property; you can only define one or the other, but not both.