gce_push_registry: Push to Google Container Registry
Description
Commit and save a running container or docker image to the Google Container Registry
Usage
gce_push_registry(instance, save_name, container_name = NULL, image_name = NULL, container_url = "gcr.io", project = gce_get_global_project(), wait = FALSE)
Arguments
instance
The VM to run within
save_name
The new name for the saved image
container_name
A running docker container. Can't be set if image_name is too.
image_name
A docker image on the instance. Can't be set if container_name is too.
container_url
The URL of where to save container
project
Project ID for this request, default as set by gce_get_global_projectThis will only work on the Google Container optimised containers of image_family google_containers.
Otherwise you will need to get a container authentication yourself (for now)
It will start the push but it may take a long time to finish, espeically the first time,
this function will return whilst waiting but don't turn off the VM until its finished.
wait
Will wait for operation to finish on the instance if TRUE
Value
The tag the image was tagged with on GCE