Learn R Programming

googleComputeEngineR (version 0.1.0)

gce_set_machinetype: Changes the machine type for a stopped instance to the machine type specified in the request.

Description

Changes the machine type for a stopped instance to the machine type specified in the request.

Usage

gce_set_machinetype(predefined_type, cpus, memory, instance, project = gce_get_global_project(), zone = gce_get_global_zone())

Arguments

predefined_type
A predefined machine type from gce_list_machinetype
cpus
If not defining predefined_type, the number of CPUs
memory
If not defining predefined_type, amount of memory
instance
Name of the instance resource to change
project
Project ID for this request, default as set by gce_get_global_project
zone
The name of the zone for this request, default as set by gce_get_global_zone

Value

A zone operation job

Details

Authentication scopes used by this function are:
  • https://www.googleapis.com/auth/cloud-platform
  • https://www.googleapis.com/auth/compute

See Also

Google Documentation