Learn R Programming

googleComputeEngineR (version 0.1.0)

gce_vm_container: Launch a container-VM image

Description

This lets you specify docker images when creating the VM

Usage

gce_vm_container(file = NULL, cloud_init = NULL, image_family = "gci-stable", ...)

Arguments

file
file location of a cloud-init file. One of file or cloud_init must be supplied
cloud_init
contents of a cloud-init file, for example read via readChar(file, nchars = 32768)
image_family
An image-family. It must come from the google-containers family.
...
Other arguments passed to gce_vm_create

file expects a filepath to a https://cloudinit.readthedocs.io/en/latest/topics/format.html configuration file.

A configuration file must be less than 32768 characters.

image_project will be ignored if set, overriden to google-containers

Value

A zone operation