gce_vm_start: Starts an instance that was stopped using the using the stop method.
Description
Starts an instance that was stopped using the using the stop method.
Usage
gce_vm_start(instance, project = gce_get_global_project(), zone = gce_get_global_zone())
Value
An Operation object with pending status
Details
Authentication scopes used by this function are:
- https://www.googleapis.com/auth/cloud-platform
- https://www.googleapis.com/auth/compute