Learn R Programming

googleComputeEngineR (version 0.1.0)

get_template_file: Show the cloud-config template files

Description

Show the cloud-config template files

Usage

get_template_file(template)

Arguments

template
This returns the file location of template files for use in gce_vm_template

Value

file location

Details

Templates available are:

  • rstudio An RStudio server docker image
  • rstudio-hadleyverse RStudio with the tidyverse installed
  • shiny A Shiny docker image
  • opencpu An OpenCPU docker image
  • r_base Latest version of R stable
  • example A non-R test container running busybox
  • dynamic Supply your own docker image to download such as rocker/verse