Rdocumentation
powered by
Learn R Programming
googleComputeEngineR (version 0.1.0)
localhost: An object representing the current computer that R is running on.
Description
An object representing the current computer that R is running on.
Usage
localhost
Arguments
Format
An object of class
localhost
(inherits from
host
) of length 0.