container_update_info: Update the information about a container.
Description
This queries docker (on the host) for information about the container, and
saves the returned information into a container object, which is returned.
This does not use reference semantics, so if you want to store the updated
information, you need to save the result.