gce_future_install_packages(instance, docker_image, cran_packages = NULL, github_packages = NULL)docker_cmd(instance, "images")If using devtools github, will look for an auth token via devtools::github_pat().
This is an environment variable called GITHUB_PAT
Will start a container, install packages and then commit
the container to an image of the same name via docker commit -m "installed packages via gceR"