Learn R Programming

googleComputeEngineR (version 0.1.0)

gce_get_zone: Returns the specified Zone resource. Get a list of available zones by making a list() request.

Description

Returns the specified Zone resource. Get a list of available zones by making a list() request.

Usage

gce_get_zone(project, zone)

Arguments

project
Project ID for this request
zone
Name of the zone resource to return

Details

Authentication scopes used by this function are:
  • https://www.googleapis.com/auth/cloud-platform
  • https://www.googleapis.com/auth/compute
  • https://www.googleapis.com/auth/compute.readonly

See Also

Google Documentation