gce_list_images(image_project, filter = NULL, maxResults = NULL, pageToken = NULL)If you want to get a list of publicly-available images, use this method to make a request to the respective image project, such as debian-cloud, windows-cloud or google-containers.