gce_ssh(instance, ..., key.pub = NULL, key.private = NULL, wait = TRUE, capture_text = FALSE, username = Sys.info()[["user"]])
gce_ssh_upload(instance, local, remote, username = Sys.info()[["user"]], key.pub = NULL, key.private = NULL, verbose = FALSE, wait = TRUE)
gce_ssh_download(instance, remote, local, username = Sys.info()[["user"]], key.pub = NULL, key.private = NULL, verbose = FALSE, overwrite = FALSE, wait = TRUE)&& so that execution will halt after the first failure.On Windows you will need to install an ssh command line client.
You will need to generate a new SSH key-pair if you have not connected to the instance before.
Otherwise, instructions for this can be found here: https://cloud.google.com/compute/docs/instances/connecting-to-instance.
When you have generated it run gce_ssh_setup once to initiate setup.
Uploads and downloads are recursive, so if you specify a directory, everything inside the directory will also be downloaded.
Other ssh functions: gce_ssh_browser,
gce_ssh_setup
## Not run:
#
# gce_ssh("rbase", "sudo journalctl -u rstudio")
#
# ## End(Not run)
Run the code above in your browser using DataLab