Learn R Programming

googleComputeEngineR (version 0.1.0)

gce_ssh_addkeys: Add SSH details to a gce_instance

Description

Add SSH details to a gce_instance

Usage

gce_ssh_addkeys(instance, key.pub = NULL, key.private = NULL, username = Sys.info()[["user"]], overwrite = FALSE)

Arguments

instance
The gce_instance
key.pub
filepath to public SSH key
key.private
filepath to the private SSK key
username
SSH username to login with
overwrite
Overwrite existing SSH details if they exist

Value

The instance with SSH details included in $ssh

Details

You will only need to run this yourself if you save your SSH keys somewhere other than $HOME/.ssh/google_compute_engine.pub or use a different username than your local username as found in Sys.info[["user"]], otherwise it will configure itself automatically the first time you use gce_ssh in an R session.

If key.pub is NULL then will look for default Google credentials at file.path(Sys.getenv("HOME"), ".ssh", "google_compute_engine.pub")