gce_tag_container(container_name, project = gce_get_global_project(), container_url = "gcr.io")image_name is too.This will only work on the Google Container optimised containers of image_family google_containers. Otherwise you will need to get a container authentication yourself (for now)
It will start the push but it may take a long time to finish, espeically the first time, this function will return whilst waiting but don't turn off the VM until its finished.