Learn R Programming

googleComputeEngineR (version 0.1.0)

gce_vm: Create or fetch a virtual machine

Description

Pass in the instance name to fetch its object, or create the instance.

Usage

gce_vm(name, ..., project = gce_get_global_project(), zone = gce_get_global_zone())

Arguments

name
The name of the instance
...
Other arguments passed to create an instance if it doesn't exist
project
Project ID for this request
zone
The name of the zone for this request

Value

A gce_instance object

Creation logic

You need these parameters defined to call the right function for creation. Check the function definitions for more details. If you specify the argument template it will call gce_vm_template If you specify one of file or cloud_init it will call gce_vm_container Otherwise it will call gce_vm_create

Details

Will get or create the instance as specified. Will wait for instance to be created if necessary.

Make sure the instance is big enough to handle what you need, for instance the default "f1-micro" will hang the instance when trying to install certain R libraries.