gce_vm(name, ..., project = gce_get_global_project(), zone = gce_get_global_zone())gce_instance object
template it will call gce_vm_template If you specify one of file or cloud_init it will call gce_vm_container Otherwise it will call gce_vm_createMake sure the instance is big enough to handle what you need, for instance the default "f1-micro" will hang the instance when trying to install certain R libraries.