gce_vm_create(name, predefined_type = "f1-micro", image_project = "debian-cloud", image_family = "debian-8", cpus = NULL, memory = NULL, image = "", disk_source = NULL, network = "default", externalIP = NULL, canIpForward = NULL, description = NULL, metadata = NULL, scheduling = NULL, serviceAccounts = NULL, tags = NULL, auth_email = "GCE_AUTH_FILE", project = gce_get_global_project(), zone = gce_get_global_zone(), dry_run = FALSE)predefined_type, the number of CPUspredefined_type, amount of memory"none" for no external access.
cpus must be in multiples of 2 up to 32
memory must be in multiples of 256
One of image or image_family must be supplied
To create an instance you need to specify:
You can add metadata to the server such as startup-script and shutdown-script. Details available here: https://cloud.google.com/compute/docs/storing-retrieving-metadata
If you want to not have an external IP then modify the instance afterwards